#[non_exhaustive]pub struct DomainCheckResult {
pub domain: String,
pub available: bool,
pub is_premium_name: bool,
pub premium_registration_price: Option<f64>,
pub error_no: Option<String>,
pub description: Option<String>,
}Expand description
The availability result for a single domain from
Domains::check.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain: StringThe domain that was checked.
available: boolWhether the domain is available to register.
Whether Namecheap classifies the domain as a premium name.
The premium registration price, when the domain is a premium name.
error_no: Option<String>A per-domain error code, when Namecheap could not check this entry
("0" indicates no error).
description: Option<String>A per-domain description or error message, when present.